@@ -1,5 +1,5 @@
 <?php
-// $Id: docs.php,v 1.13 2009/02/06 21:56:36 merlinofchaos Exp $
+// $Id: docs.php,v 1.16.2.1 2009/11/30 23:55:33 merlinofchaos Exp $
 /**
  * @file
  * This file contains no working PHP code; it exists to provide additional documentation
@@ -219,6 +219,14 @@ function hook_views_plugins() {
   // example code here
 }
 
+/**
+ * Alter existing plugins data, defined by modules.
+ */
+function hook_views_plugins_alter(&$plugins) {
+  // Add apachesolr to the base of the node row plugin.
+  $plugins['row']['node']['base'][] = 'apachesolr';
+}
+
 /**
  * Register handler, file and parent information so that handlers can be
  * loaded only on request.
@@ -231,11 +239,21 @@ function hook_views_handlers() {
 
 /**
  * Register View API information. This is required for your module to have
- * its include files loaded.
+ * its include files loaded; for example, when implementing
+ * hook_views_default_views().
  *
- * The full documentation for this hook is in the advanced help.
+ * @return
+ *   An array with the following possible keys:
+ *   - api:  (required) The version of the Views API the module implements.
+ *   - path: (optional) If includes are stored somewhere other than within
+ *       the root module directory or a subdirectory called includes, specify
+ *       its path here.
  */
 function hook_views_api() {
+  return array(
+    'api' => 2,
+    'path' => drupal_get_path('module', 'example') . '/includes/views', 
+  );
 }
 
 /**
@@ -495,6 +513,17 @@ function hook_views_default_views() {
   return $views;
 }
 
+/**
+ * This hook is called right before all default views are cached to the
+ * database. It takes a keyed array of views by reference.
+ */
+function hook_views_default_views_alter(&$views) {
+  if (isset($views['taxonomy_term'])) {
+    $views['taxonomy_term']->set_display('default');
+    $views['taxonomy_term']->display_handler->set_option('title', 'Categories');
+  }
+}
+
 /**
  * Stub hook documentation
  *
@@ -553,11 +582,39 @@ function hook_views_pre_execute(&$view) {
  *
  * Adding output to the view cam be accomplished by placing text on
  * $view->attachment_before and $view->attachment_after
+ *
+ * This hook can be utilized by themes.
  */
 function hook_views_pre_render(&$view) {
   // example code here
 }
 
+/**
+ * Post process any rendered data.
+ *
+ * This can be valuable to be able to cache a view and still have some level of
+ * dynamic output. In an ideal world, the actual output will include HTML
+ * comment based tokens, and then the post process can replace those tokens.
+ *
+ * Example usage. If it is known that the view is a node view and that the
+ * primary field will be a nid, you can do something like this:
+ *
+ * <!--post-FIELD-NID-->
+ *
+ * And then in the post render, create an array with the text that should
+ * go there:
+ *
+ * strtr($output, array('<!--post-FIELD-1-->', 'output for FIELD of nid 1');
+ *
+ * All of the cached result data will be available in $view->result, as well,
+ * so all ids used in the query should be discoverable.
+ *
+ * This hook can be utilized by themes.
+ */
+function hook_views_post_render(&$view, &$output, &$cache) {
+
+}
+
 /**
  * Stub hook documentation
  *
